==> react-web-notification-0.6.1.tgz: package/karma.conf.js <==
// Karma configuration
// Generated on Fri May 15 2015 12:31:20 GMT+0900 (JST)

module.exports = function(config) {
  config.set({

    // base path that will be used to resolve all patterns (eg. files, exclude)
    basePath: '',


    // frameworks to use
    // available frameworks: https://npmjs.org/browse/keyword/karma-adapter
    frameworks: ['browserify','mocha'],


    // list of files / patterns to load in the browser
    files: [
      'test/**/*_spec.js',
      { pattern: 'node_modules/sinon/pkg/sinon.js', watched: false, included: true }
    ],


    // list of files to exclude
    exclude: [
      'test/_helper/*.js'
    ],


    // preprocess matching files before serving them to the browser
    // available preprocessors: https://npmjs.org/browse/keyword/karma-preprocessor
    preprocessors: {
      'test/**/*_spec.js': ['browserify']
    },

    browserify: {
      debug: true,
      'transform': [
        [
          'babelify',
        ]
      ]
    },

    // test results reporter to use
    // possible values: 'dots', 'progress'
    // available reporters: https://npmjs.org/browse/keyword/karma-reporter
    reporters: ['spec'],

    // client: {
    //   mocha: {
    //     // reporter: 'html', // change Karma's debug.html to the mocha web reporter
    //     // ui: 'tdd'
    //   }
    // },

    // web server port
    port: 9876,


    // enable / disable colors in the output (reporters and logs)
    colors: true,


    // level of logging
    // possible values: config.LOG_DISABLE || config.LOG_ERROR || config.LOG_WARN || config.LOG_INFO || config.LOG_DEBUG
    logLevel: config.LOG_INFO,


    // enable / disable watching file and executing tests whenever any file changes
    autoWatch: true,


    // start these browsers
    // available browser launchers: https://npmjs.org/browse/keyword/karma-launcher
    // browsers: ['Chrome', 'Firefox', 'PhantomJS', 'IE'],
    browsers: [process.env.CONTINUOUS_INTEGRATION ? 'Firefox' : 'Chrome'],


    // Continuous Integration mode
    // if true, Karma captures browsers, runs the tests and exits
    singleRun: false
  });
};

==> react-web-notification-0.7.0.tgz: package/karma.conf.js <==
// Karma configuration
// Generated on Fri May 15 2015 12:31:20 GMT+0900 (JST)

module.exports = function(config) {
  config.set({

    // base path that will be used to resolve all patterns (eg. files, exclude)
    basePath: '',


    // frameworks to use
    // available frameworks: https://npmjs.org/browse/keyword/karma-adapter
    frameworks: ['browserify','mocha'],


    // list of files / patterns to load in the browser
    files: [
      'test/**/*_spec.js',
      { pattern: 'node_modules/sinon/pkg/sinon.js', watched: false, included: true }
    ],


    // list of files to exclude
    exclude: [
      'test/_helper/*.js'
    ],


    // preprocess matching files before serving them to the browser
    // available preprocessors: https://npmjs.org/browse/keyword/karma-preprocessor
    preprocessors: {
      'test/**/*_spec.js': ['browserify'],
      'src/**/*.js': ['coverage']
    },

    browserify: {
      debug: true,
      'transform': [
        [
          'babelify',{
            "presets": [
              ["@babel/env",{
                  "useBuiltIns": "entry",
                  "corejs": 3
                }
              ],
              "@babel/react"
            ],
            "plugins": [
              "istanbul",
            ],
          }
        ]
      ]
    },

    // test results reporter to use
    // possible values: 'dots', 'progress'
    // available reporters: https://npmjs.org/browse/keyword/karma-reporter
    reporters: ['spec', 'coverage'],

     coverageReporter: {
      reporters: [
        // reporters not supporting the `file` property
        {type:'lcovonly', subdir: '.'},
        { type: 'text' },
      ]
    },

    // client: {
    //   mocha: {
    //     // reporter: 'html', // change Karma's debug.html to the mocha web reporter
    //     // ui: 'tdd'
    //   }
    // },

    // web server port
    port: 9876,


    // enable / disable colors in the output (reporters and logs)
    colors: true,


    // level of logging
    // possible values: config.LOG_DISABLE || config.LOG_ERROR || config.LOG_WARN || config.LOG_INFO || config.LOG_DEBUG
    logLevel: config.LOG_INFO,


    // enable / disable watching file and executing tests whenever any file changes
    autoWatch: true,


    // start these browsers
    // available browser launchers: https://npmjs.org/browse/keyword/karma-launcher
    // browsers: ['Chrome', 'Firefox', 'PhantomJS', 'IE'],
    browsers: [process.env.CONTINUOUS_INTEGRATION ? 'Firefox' : 'Chrome'],


    // Continuous Integration mode
    // if true, Karma captures browsers, runs the tests and exits
    singleRun: false
  });
};
